<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['device:radar:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['device:radar:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['device:radar:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['device:radar:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="radarList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="图像高度" align="center" prop="imageHeight">
        <template slot-scope="scope">
          </template>
      </el-table-column>
      <el-table-column label="安装时间" align="center" prop="radarDate">
        <template slot-scope="scope">
           </template>
      </el-table-column>
      <el-table-column label="用户id" align="center" prop="userId">
        <template slot-scope="scope">
        </template>
      </el-table-column>
      <el-table-column label="型号" align="center" prop="type">
        <template slot-scope="scope">
         </template>
      </el-table-column>
      <el-table-column label="ip" align="center" prop="ip">
        <template slot-scope="scope">
         </template>
      </el-table-column>
      <el-table-column label="端口" align="center" prop="port">
        <template slot-scope="scope">
          </template>
      </el-table-column>
      <el-table-column label="操作员id" align="center" prop="operate">
        <template slot-scope="scope">
        </template>
      </el-table-column>
      <el-table-column label="高程" align="center" prop="altitude">
        <template slot-scope="scope">
        </template>
      </el-table-column>
      <el-table-column label="经度" align="center" prop="longitude">
        <template slot-scope="scope">
          </template>
      </el-table-column>
      <el-table-column label="维度" align="center" prop="latitude">
        <template slot-scope="scope">
        </template>
      </el-table-column>
      <el-table-column label="部门id" align="center" prop="deptId">
        <template slot-scope="scope">
         </template>
      </el-table-column>
      <el-table-column label="俯仰角" align="center" prop="pitch">
        <template slot-scope="scope">
        </template>
      </el-table-column>
      <el-table-column label="塔id" align="center" prop="towerId">
        <template slot-scope="scope">
        </template>
      </el-table-column>
      <el-table-column label="图像宽度" align="center" prop="imageWidth">
        <template slot-scope="scope">
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['device:radar:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['device:radar:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改radar对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="id" prop="id">
          <el-input v-model="form.id" placeholder="请输入id" />
        </el-form-item>
        <el-form-item label="图像高度" prop="imageHeight">
          <el-input v-model="form.imageHeight" placeholder="请输入图像高度" />
        </el-form-item>
        <el-form-item label="安装时间" prop="radarDate">
          <el-input v-model="form.radarDate" placeholder="请输入安装时间" />
        </el-form-item>
        <el-form-item label="用户id" prop="userId">
          <el-input v-model="form.userId" placeholder="请输入用户id" />
        </el-form-item>
        <el-form-item label="型号" prop="type">
          <el-input v-model="form.type" placeholder="请输入型号" />
        </el-form-item>
        <el-form-item label="ip" prop="ip">
          <el-input v-model="form.ip" placeholder="请输入ip" />
        </el-form-item>
        <el-form-item label="端口" prop="port">
          <el-input v-model="form.port" placeholder="请输入端口" />
        </el-form-item>
        <el-form-item label="操作员id" prop="operate">
          <el-input v-model="form.operate" placeholder="请输入操作员id" />
        </el-form-item>
        <el-form-item label="部门id" prop="deptId">
          <el-input v-model="form.deptId" placeholder="请输入部门id" />
        </el-form-item>
        <el-form-item label="俯仰角" prop="pitch">
          <el-input v-model="form.pitch" placeholder="请输入俯仰角" />
        </el-form-item>
        <el-form-item label="塔id" prop="towerId">
          <el-input v-model="form.towerId" placeholder="请输入塔id" />
        </el-form-item>
        <el-form-item label="图像宽度" prop="imageWidth">
          <el-input v-model="form.imageWidth" placeholder="请输入图像宽度" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listRadar, getRadar, delRadar, addRadar, updateRadar } from "@/api/device/radar";

export default {
  name: "Radar",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // radar表格数据
      radarList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询radar列表 */
    getList() {
      this.loading = true;
      listRadar(this.queryParams).then(response => {
        this.radarList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        createTime: null,
        updateTime: null,
        imageHeight: null,
        radarDate: null,
        createBy: null,
        updateBy: null,
        delFlag: null,
        userId: null,
        type: null,
        ip: null,
        port: null,
        operate: null,
        altitude: null,
        longitude: null,
        latitude: null,
        deptId: null,
        pitch: null,
        towerId: null,
        imageWidth: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加radar";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getRadar(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改radar";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateRadar(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addRadar(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除radar编号为"' + ids + '"的数据项？').then(function() {
        return delRadar(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('device/radar/export', {
        ...this.queryParams
      }, `radar_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
